import { useState } from 'react';
import {
    MagnifyingGlassIcon,
    StarIcon,
    TrashIcon,
    EnvelopeIcon,
    FunnelIcon,
} from '@heroicons/react/24/outline';
import { StarIcon as StarIconSolid } from '@heroicons/react/24/solid';

interface Letter {
    id: string;
    sender: string;
    subject: string;
    date: string;
    priority: 'high' | 'medium' | 'low';
    isRead: boolean;
    isStarred: boolean;
}

export default function LetterListPage() {
    const [letters, setLetters] = useState<Letter[]>([
        {
            id: '1',
            sender: 'Gen. Charles Q. Brown Jr.',
            subject: 'Strategic Force Posture Update',
            date: '2024-01-22',
            priority: 'high',
            isRead: false,
            isStarred: true,
        },
        // ... existing code ...
    ]);

    const [searchTerm, setSearchTerm] = useState('');
    const [selectedFilter, setSelectedFilter] = useState('all');

    return (
        <div className="min-h-screen bg-gray-50">
            {/* Header */}
            <header className="bg-[#00538B] text-white p-4 shadow-lg">
                <div className="container mx-auto flex items-center gap-2">
                    <EnvelopeIcon className="w-8 h-8" />
                    <h1 className="text-2xl font-bold">USAF Leadership Mailbox</h1>
                </div>
            </header>

            {/* Main Content */}
            <main className="container mx-auto py-6 px-4">
                {/* Search and Filter Bar */}
                <div className="flex gap-4 mb-6">
                    <div className="flex-1 relative">
                        <MagnifyingGlassIcon className="absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400 w-5 h-5" />
                        <input
                            type="text"
                            placeholder="Search letters..."
                            className="w-full pl-10 pr-4 py-2 border border-gray-300 rounded-lg focus:ring-2 focus:ring-[#00538B] focus:border-transparent"
                            value={searchTerm}
                            onChange={(e) => setSearchTerm(e.target.value)}
                        />
                    </div>
                    <div className="relative">
                        <FunnelIcon className="absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400 w-5 h-5" />
                        <select
                            className="pl-10 pr-4 py-2 border border-gray-300 rounded-lg focus:ring-2 focus:ring-[#00538B] appearance-none bg-white"
                            value={selectedFilter}
                            onChange={(e) => setSelectedFilter(e.target.value)}
                        >
                            <option value="all">All Letters</option>
                            <option value="unread">Unread</option>
                            <option value="starred">Starred</option>
                            <option value="high">High Priority</option>
                        </select>
                    </div>
                </div>

                {/* Letters List */}
                <div className="bg-white rounded-lg shadow">
                    {letters.map((letter) => (
                        <div
                            key={letter.id}
                            className={`flex items-center p-4 border-b border-gray-100 hover:bg-gray-50 cursor-pointer transition-colors ${!letter.isRead ? 'font-semibold bg-blue-50' : ''
                                }`}
                        >
                            <div className="flex items-center gap-4 flex-1">
                                <button
                                    className="focus:outline-none"
                                    onClick={() => {/* Toggle star */ }}
                                >
                                    {letter.isStarred ? (
                                        <StarIconSolid className="w-6 h-6 text-yellow-400" />
                                    ) : (
                                        <StarIcon className="w-6 h-6 text-gray-400 hover:text-yellow-400" />
                                    )}
                                </button>
                                <div className="flex-1">
                                    <div className="flex items-center gap-2">
                                        <span className="text-gray-900">{letter.sender}</span>
                                        {letter.priority === 'high' && (
                                            <span className="px-2 py-1 text-xs bg-red-100 text-red-800 rounded-full">
                                                High Priority
                                            </span>
                                        )}
                                    </div>
                                    <div className="text-gray-600">{letter.subject}</div>
                                </div>
                                <div className="text-sm text-gray-500">{letter.date}</div>
                                <button className="p-1 rounded-full hover:bg-gray-100 focus:outline-none">
                                    <TrashIcon className="w-5 h-5 text-gray-400 hover:text-red-500" />
                                </button>
                            </div>
                        </div>
                    ))}
                </div>
            </main>
        </div>
    );
}
